@@ -1,44 +1,45 @@
 import os, sqlite3
 from typing import Any, Iterable, List, Optional, Union
 
-from sqlite_utils import Database
-
 from xklb.utils import log
 
 
-class DB(Database):
-    def pop(self, sql: str, params: Optional[Union[Iterable, dict]] = None, ignore_errors=None) -> Optional[Any]:
-        if ignore_errors is None:
-            ignore_errors = ["no such table"]
-        try:
-            curs = self.execute(sql, params)
-            data = curs.fetchone()
-        except sqlite3.OperationalError as exc:
-            if any([e in str(exc) for e in ignore_errors]):
-                return None
-            raise
-        if data is None or len(data) == 0:
-            return None
-        return data[0]
-
-    def pop_dict(self, sql: str, params: Optional[Union[Iterable, dict]] = None, ignore_errors=None) -> Optional[Any]:
-        if ignore_errors is None:
-            ignore_errors = ["no such table"]
-        try:
-            dg = self.query(sql, params)
-            d = next(dg, None)
-        except sqlite3.OperationalError as exc:
-            if any([e in str(exc) for e in ignore_errors]):
-                return None
-            raise exc
-        return d
-
-
 def tracer(sql, params) -> None:
     print("SQL: {} - params: {}".format(sql, params))
 
 
-def connect(args, conn=None, **kwargs) -> Database:
+def connect(args, conn=None, **kwargs):
+    from sqlite_utils import Database
+
+    class DB(Database):
+        def pop(self, sql: str, params: Optional[Union[Iterable, dict]] = None, ignore_errors=None) -> Optional[Any]:
+            if ignore_errors is None:
+                ignore_errors = ["no such table"]
+            try:
+                curs = self.execute(sql, params)
+                data = curs.fetchone()
+            except sqlite3.OperationalError as exc:
+                if any([e in str(exc) for e in ignore_errors]):
+                    return None
+                raise
+            if data is None or len(data) == 0:
+                return None
+            return data[0]
+
+        def pop_dict(
+            self, sql: str, params: Optional[Union[Iterable, dict]] = None, ignore_errors=None
+        ) -> Optional[Any]:
+            if ignore_errors is None:
+                ignore_errors = ["no such table"]
+            try:
+                dg = self.query(sql, params)
+                d = next(dg, None)
+            except sqlite3.OperationalError as exc:
+                if any([e in str(exc) for e in ignore_errors]):
+                    return None
+                raise exc
+            return d
+
     if not os.path.exists(args.database) and ":memory:" not in args.database:
         log.error(f"Database file '{args.database}' does not exist. Create one with lb fsadd, tubeadd, or tabsadd.")
         raise SystemExit(1)
@@ -51,7 +52,7 @@ def connect(args, conn=None, **kwargs) -> Database:
 
 def optimize(args) -> None:
     print("\nOptimizing database")
-    db: Database = args.db
+    db = args.db
     db.enable_wal()
 
     config = {
