@@ -25,13 +25,13 @@ def usage() -> str:
 
       lb listen                Listen to local and online media
       lb watch                 Watch local and online media
+      lb read                  Read books
+      lb view                  View images
 
       lb bigdirs               Discover folders which take much room
       lb dedupe                Deduplicate audio files
-      lb christen              Cleanse files by giving them a new name
 
-      lb read                  Read books
-      lb view                  View images
+      lb christen              Cleanse files by giving them a new name
 
     online media:
       lb tubeadd               Create a tube database; Add playlists
@@ -43,6 +43,7 @@ def usage() -> str:
     downloads:
       lb download              Download media
       lb block                 Prevent downloading specific URLs
+      lb merge-dbs             Merge multiple SQLITE files
       lb merge-online-local    Merge local and online metadata
 
     playback:
@@ -91,7 +92,7 @@ def add_parser(subparsers, name, a=None):
     return subparsers.add_parser(name, aliases=aliases, add_help=False)
 
 
-def lb(args=None) -> None:
+def library(args=None) -> None:
     if args:
         sys.argv[2:] = args
 
@@ -125,7 +126,9 @@ def lb(args=None) -> None:
     subp_dedupe = add_parser(subparsers, "dedupe")
     subp_dedupe.set_defaults(func=scripts.deduplicate_music)
     subp_christen = add_parser(subparsers, "christen")
-    subp_christen.set_defaults(func=scripts.rename_invalid_files)
+    subp_christen.set_defaults(func=scripts.rename_invalid_paths)
+    subp_merge_db = add_parser(subparsers, "merge-dbs")
+    subp_merge_db.set_defaults(func=scripts.merge_dbs)
     subp_dedupe_local = add_parser(subparsers, "merge-online-local")
     subp_dedupe_local.set_defaults(func=scripts.merge_online_local)
     subp_optimize = add_parser(subparsers, "optimize")
@@ -151,7 +154,7 @@ def lb(args=None) -> None:
     subp_block = add_parser(subparsers, "block")
     subp_block.set_defaults(func=dl_block)
 
-    subp_playlist = add_parser(subparsers, "playlists", ["pl", "tubelist", "folders"])
+    subp_playlist = add_parser(subparsers, "playlists", ["pl", "folders"])
     subp_playlist.set_defaults(func=playlists)
     subp_dlstatus = add_parser(subparsers, "dlstatus", ["ds"])
     subp_dlstatus.set_defaults(func=dlstatus)
@@ -185,6 +188,7 @@ def lb(args=None) -> None:
     if args.version:
         return print(__version__)
 
+    log.info("library v%s", __version__)
     log.info(sys.argv)
     original_argv = sys.argv
     if len(sys.argv) >= 2:
@@ -201,9 +205,5 @@ def lb(args=None) -> None:
         print_help(parser)
 
 
-def main() -> None:
-    lb()
-
-
 if __name__ == "__main__":
-    main()
+    library()
