@@ -152,7 +152,7 @@ def usage(action, default_db) -> str:
         library {action} -w 'duration is null' -p=a
 
         Print a list of filenames which have below 1280px resolution
-        library wt -w 'width<1280' -p=f
+        library {action} -w 'width<1280' -p=f
 
         Print media you have partially viewed with mpv
         library {action} -p=v
@@ -161,7 +161,7 @@ def usage(action, default_db) -> str:
         library {action} -w play_count'>'0 -p=a
 
         See how much video you have
-        library wt video.db -p=a
+        library {action} video.db -p=a
         ╒═══════════╤═════════╤═════════╤═════════╕
         │ path      │   hours │ size    │   count │
         ╞═══════════╪═════════╪═════════╪═════════╡
@@ -257,7 +257,7 @@ def usage(action, default_db) -> str:
         library {action} --sort duration   # play shortest media first
         library {action} -u duration desc  # play longest media first
         You can use multiple SQL ORDER BY expressions
-        library {action} -u subtitle_count > 0 desc # play media that has at least one subtitle first
+        library {action} -u 'subtitle_count > 0 desc' # play media that has at least one subtitle first
 
     Play media in order (similarly named episodes):
         library {action} --play-in-order
@@ -387,7 +387,7 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     parser.add_argument("--mpv-socket", default=consts.DEFAULT_MPV_SOCKET, help=argparse.SUPPRESS)
     parser.add_argument("--watch-later-directory", default=consts.DEFAULT_MPV_WATCH_LATER, help=argparse.SUPPRESS)
 
-    parser.add_argument("--player", "-player", help=argparse.SUPPRESS)
+    parser.add_argument("--override-player", "--player", "-player", help=argparse.SUPPRESS)
     parser.add_argument(
         "--player-args-sub", "-player-sub", nargs="*", default=DEFAULT_PLAYER_ARGS_SUB, help=argparse.SUPPRESS
     )
@@ -401,7 +401,7 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
     parser.add_argument("--shallow-organize", default="/mnt/d/", help=argparse.SUPPRESS)
 
     parser.add_argument("--db", "-db", help=argparse.SUPPRESS)
-    parser.add_argument("--ignore-errors", "--ignoreerrors", "-i", action="store_true", help=argparse.SUPPRESS)
+    parser.add_argument("--ignore-errors", "--ignoreerrors", "-i", action="store_true")
     parser.add_argument("--safe", "-safe", action="store_true", help="Skip generic URLs")
     parser.add_argument("--verbose", "-v", action="count", default=0)
 
@@ -467,8 +467,8 @@ def parse_args(action, default_db, default_chromecast="") -> argparse.Namespace:
         args.cc = CattDevice(args.chromecast_device, lazy=True)
         args.cc_ip = utils.get_ip_of_chromecast(args.chromecast_device)
 
-    if args.player:
-        args.player = shlex.split(args.player)
+    if args.override_player:
+        args.override_player = shlex.split(args.override_player)
 
     log.info(utils.dict_filter_bool(args.__dict__))
 
